OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Đã đính kèm tin nhắn %s",
    "Important mail" : "Thư quan trọng",
    "Unread mail" : "Thư chưa đọc",
    "Important" : "Quan trọng",
    "Work" : "Công việc",
    "Personal" : "Cá nhân",
    "To Do" : "Việc cần làm",
    "Later" : "Để sau",
    "Mails" : "Thư",
    "Mail" : "Thư",
    "💌 A mail app for Nextcloud" : "💌 Ứng dụng mail cho vWorkspace",
    "Drafts are saved in:" : "Thư nháp được lưu trong:",
    "Sent messages are saved in:" : "Tin nhắn đã gửi được lưu trong:",
    "Deleted messages are moved in:" : "Tin nhẵn đã xóa được chuyển tới:",
    "Auto" : "Tự động",
    "Name" : "Tên",
    "Password" : "Mật khẩu",
    "Manual" : "Thủ công",
    "IMAP Settings" : "Cài đặt IMAP",
    "IMAP Security" : "Bảo mật IMAP",
    "None" : "Không có",
    "IMAP Port" : "Cổng IMAP",
    "IMAP User" : "Người dùng IMAP",
    "IMAP Password" : "Mật khẩu IMAP",
    "SMTP Settings" : "Cài đặt SMTP",
    "SMTP Security" : "Bảo mật SMTP",
    "SMTP Port" : "Cổng SMTP",
    "SMTP User" : "Người dùng SMTP",
    "SMTP Password" : "Mật khẩu SMTP",
    "Save" : "Lưu",
    "Connect" : "Kết nối",
    "Account settings" : "Cài đặt tài khoản",
    "Change name" : "Đổi tên",
    "Signature" : "Chữ ký",
    "A signature is added to the text of new messages and replies." : "Chữ ký được thêm vào tin nhắn và thư trả lời mới.",
    "Writing mode" : "Chế độ soạn thảo",
    "Preferred writing mode for new messages and replies." : "Chế độ soạn thảo ưu tiên cho các tin nhắn và trả lời mới.",
    "Default folders" : "Thư mục mặc định",
    "Sieve filter rules" : "Quy tắc lọc Sieve",
    "Trusted senders" : "Người gửi đáng tin cậy",
    "Mail server" : "Máy chủ thư",
    "Sieve filter server" : "Máy chủ lọc Sieve",
    "Email address" : "Địa chỉ thư điện tử",
    "Add alias" : "Thêm bí danh",
    "Cancel" : "Hủy bỏ",
    "Add mail account" : "Thêm tài khoản mail",
    "Use Gravatar and favicon avatars" : "Sử dụng hình đại diện Gravatar và favicon",
    "Register as application for mail links" : "Đăng ký làm ứng dụng cho các liên kết gửi thư",
    "Show keyboard shortcuts" : "Hiển thị phím tắt",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Cho phép ứng dụng thu thập dữ liệu về các tương tác của bạn. Dựa trên dữ liệu này, ứng dụng sẽ điều chỉnh theo sở thích của bạn. Dữ liệu sẽ chỉ được lưu trữ trên máy của bạn.",
    "Put my text to the bottom of a reply instead of on top of it." : "Đặt văn bản ở cuối thư trả lời thay vì ở đầu thư.",
    "From" : "Từ",
    "Select account" : "Chọn tài khoản",
    "To" : "Tới",
    "Contact or email address …" : "Địa chỉ liên hệ hoặc thư điện tử …",
    "No contacts found." : "Không tìm thấy địa chỉ liên hệ.",
    "Subject" : "Chủ đề",
    "Subject …" : "Chủ đề …",
    "This message came from a noreply address so your reply will probably not be read." : "Thư này đến từ một địa chỉ không trả lời nên có thể sẽ không đọc được thư trả lời của bạn.",
    "The following recipients do not have a PGP key: {recipients}." : "Những người nhận sau không có khóa PGP: {recipients}.",
    "Write message …" : "Viết tin nhắn …",
    "Saving draft …" : "Đang lưu bản nháp …",
    "Draft saved" : "Bản nháp đã được lưu",
    "Upload attachment" : "Tải lên một đính kèm",
    "Add attachment from Files" : "Thêm tệp đính kèm từ Tệp",
    "Enable formatting" : "Bật định dạng",
    "Request a read receipt" : "Yêu cầu xác nhận đã đọc",
    "Encrypt message with Mailvelope" : "Mã hóa thư bằng Mailvelope",
    "Uploading attachments …" : "Đang tải lên các tệp đính kèm …",
    "Sending …" : "Đang gửi …",
    "Error sending your message" : "Lỗi khi gửi tin nhắn",
    "Go back" : "Quay lại",
    "Retry" : "Thử lại",
    "Message sent!" : "Đã gửi tin nhắn!",
    "Add share link from {productName} Files" : "Thêm liên kết chia sẻ từ Tệp {productName}",
    "Send" : "Gởi",
    "Encrypt and send" : "Mã hóa và gửi",
    "Send unencrypted" : "Gửi không mã hóa",
    "Message {id} could not be found" : "Không tìm thấy tin nhắn {id}",
    "No sent mailbox configured. Please pick one in the account settings." : "Không có hộp thư đã gửi nào được định cấu hình. Vui lòng chọn một trong cài đặt tài khoản.",
    "Choose a file to add as attachment" : "Chọn một tệp để thêm dưới dạng tệp đính kèm",
    "Choose a file to share as a link" : "Chọn một tệp để chia sẻ dưới dạng liên kết",
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Các tệp đính kèm vượt quá kích thước được cho phép là {size}. Thay vào đó, hãy chia sẻ các tệp qua liên kết."],
    "No message found yet" : "Không có tin nhắn nào được tìm thấy",
    "Set up an account" : "Thiết lập một tài khoản",
    "No messages in this mailbox" : "Không có thư nào trong hộp thư này",
    "No messages" : "Không có tin nhắn",
    "Draft: " : "Bản nháp: ",
    "Favorite" : "Ưa thích",
    "Read" : "Đọc",
    "Mark not spam" : "Đánh dấu không phải là thư rác",
    "Mark as spam" : "đánh dấu spam",
    "Unselect" : "Bỏ chọn",
    "Select" : "Select",
    "Edit tags" : "Sửa thẻ",
    "Move" : "Dịch chuyển",
    "More actions" : "Nhiều hành động hơn",
    "Edit as new message" : "Chỉnh sửa dưới dạng tin nhắn mới",
    "Create event" : "Tạo sự kiện mới",
    "Blind copy recipients only" : "Chỉ người nhận bản sao ẩn",
    "No trash mailbox configured" : "Không có hộp thư thùng rác nào được định cấu hình",
    "Could not delete message" : "Không thể xóa tin nhắn",
    "Forward" : "Chuyển tiếp",
    "Load more" : "Tải thêm",
    "_Mark {number} unread_::_Mark {number} unread_" : ["Đánh dấu {number} là chưa đọc"],
    "_Mark {number} read_::_Mark {number} read_" : ["Đánh dấu {number} đã đọc"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Bỏ yêu thích {number}"],
    "_Favorite {number}_::_Favorite {number}_" : ["Yêu thích {number}"],
    "_Unselect {number}_::_Unselect {number}_" : ["Bỏ chọn {number}"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Chuyển tiếp {number} dưới dạng tệp đính kèm"],
    "Report this bug" : "Báo cáo lỗi này",
    "All day" : "Cả ngày",
    "Create" : "‎Tạo‎",
    "Could not create event" : "Không thể tạo sự kiện",
    "Comment" : "Bình luận",
    "Accept" : "Đồng ý",
    "Could not open mailbox" : "Không thể mở hộp thư",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Lập chỉ mục tin nhắn của bạn. Quá trình này có thể lâu hơn một chút đối với các hộp thư lớn.",
    "Choose target mailbox" : "Chọn hộp thư mục tiêu",
    "No more submailboxes in here" : "Không còn hộp thư con nào ở đây",
    "Choose" : "Chọn",
    "Important info" : "Thông tin quan trọng",
    "Other" : "Khác",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Tin nhắn sẽ tự động được đánh dấu là quan trọng dựa trên những tin nhắn bạn đã tương tác hoặc được đánh dấu là quan trọng. Lúc đầu, bạn có thể phải thay đổi thủ công tầm quan trọng để dạy hệ thống, nhưng nó sẽ cải thiện theo thời gian.",
    "The sender of this message has asked to be notified when you read this message." : "Người gửi tin nhắn này đã yêu cầu được thông báo khi bạn đọc tin nhắn này.",
    "Notify the sender" : "Thông báo cho người gửi",
    "You sent a read confirmation to the sender of this message." : "Bạn đã gửi xác nhận đã đọc cho người gửi tin nhắn này.",
    "Could not send mdn" : "Không thể gửi mdn",
    "Reply" : "Trả lời",
    "Reply to sender only" : "Chỉ trả lời người gửi",
    "View source" : "Xem nguồn",
    "Download thread data for debugging" : "Tải xuống dữ liệu chuỗi để gỡ lỗi",
    "Message source" : "Nguồn tin nhắn",
    "Message body" : "Nội dung thư",
    "Import into calendar" : "Nhập vào lịch",
    "Download attachment" : "Tải xuống Tệp đính kèm",
    "Save to Files" : "Lưu vào Tệp",
    "Unnamed" : "Vô danh",
    "Embedded message" : "Tin nhắn đã đính kém",
    "Choose a folder to store the attachment in" : "Chọn một thư mục để lưu trữ tệp đính kèm trong",
    "Save all to Files" : "Lưu tất cả vào Tệp",
    "Download Zip" : "Tải xuống định dạng Zip",
    "Choose a folder to store the attachments in" : "Chọn một thư mục để lưu trữ các tệp đính kèm trong",
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Thư này được mã hóa bằng PGP. Cài đặt Mailvelope để giải mã nó",
    "The images have been blocked to protect your privacy." : "Các hình ảnh đã bị chặn để bảo vệ sự riêng tư của bạn.",
    "Show images temporarily" : "Hiển thị hình ảnh tạm thời",
    "Always show images from {sender}" : "Luôn hiển thị hình ảnh từ {sender}",
    "Always show images from {domain}" : "Luôn hiển thị hình ảnh từ {domain}",
    "Message frame" : "Khung tin nhắn",
    "Quoted text" : "Văn bản được trích dẫn",
    "Moving" : "Di chuyển",
    "Quota" : "Hạn ngạch",
    "Show only subscribed mailboxes" : "Chỉ hiển thị các hộp thư đã đăng ký",
    "Add mailbox" : "Thêm hộp thư",
    "Saving" : "Tiết kiệm",
    "Move up" : "Di chuyển lên",
    "Move down" : "Di chuyển xuống",
    "Remove account" : "Xóa tài khoản",
    "Loading …" : "Đang tải...",
    "Not supported by the server" : "Không được máy chủ hỗ trợ",
    "{usage} of {limit} used" : "Đã sử dụng {use} trong tổng số {limit}",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Tài khoản cho {email} và dữ liệu email đã lưu trong bộ nhớ cache sẽ bị xóa khỏi vWorkspace, nhưng không bị xóa khỏi nhà cung cấp dịch vụ email của bạn.",
    "Remove account {email}" : "Xóa tài khoản {email}",
    "Remove {email}" : "Xóa {email}",
    "Show all subscribed mailboxes" : "Hiển thị tất cả các hộp thư đã đăng ký",
    "Show all mailboxes" : "Hiển thị tất cả các hộp thư",
    "Collapse mailboxes" : "Thu gọn hộp thư",
    "Mark all as read" : "Đánh dấu tất cả như đã ",
    "Mark all messages of this mailbox as read" : "Đánh dấu tất cả các thư của hộp thư này là đã đọc",
    "Add submailbox" : "Thêm hộp thư con",
    "Edit name" : "Sửa đổi tên",
    "Clear cache" : "Xóa bộ nhớ ",
    "Clear locally cached data, in case there are issues with synchronization." : "Xóa dữ liệu được lưu trong bộ nhớ cache cục bộ, trong trường hợp có sự cố với đồng bộ hóa.",
    "Subscribed" : "Đã đăng ký",
    "Sync in background" : "Đồng bộ trong nền",
    "Delete mailbox" : "Xóa hộp thư",
    "The mailbox and all messages in it will be deleted." : "Hộp thư và tất cả thư trong đó sẽ bị xóa.",
    "Delete mailbox {name}" : "Xóa hộp thư {name}",
    "An error occurred, unable to rename the mailbox." : "Đã xảy ra lỗi, không thể đổi tên hộp thư.",
    "_{total} message_::_{total} messages_" : ["{total} tin nhắn"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} thư chưa đọc trong tổng số {total} thư"],
    "New message" : "Tin nhắn mới",
    "No message selected" : "Không có tin nhắn nào được chọn",
    "Delete" : "Xóa",
    "Contacts with this address" : "Liên hệ với địa chỉ này",
    "Add to Contact" : "Thêm liên hệ",
    "New Contact" : "ĐỊa chỉ liên hệ mới",
    "Contact name …" : "Tên người liên hệ …",
    "Add" : "Thêm",
    "Tags" : "Nhãn",
    "Select tags" : "Chọn một thẻ",
    "Clear" : "Xóa",
    "Search" : "Tìm",
    "Date" : "Date",
    "Disabled" : "Đã vô hiệu",
    "Enabled" : "Đá kích hoạt",
    "Sieve Security" : "Bảo mật Sieve",
    "Sieve Port" : "Cổng Sieve",
    "Sieve Credentials" : "Thông tin xác thực Sieve",
    "IMAP Credentials" : "Thông tin xác thực IMAP",
    "Custom" : "Tùy chỉnh",
    "Sieve User" : "Người dùng Sieve",
    "Sieve Password" : "Mật khẩu Sieve",
    "Save sieve settings" : "Lưu cài đặt sieve",
    "Save sieve script" : "Lưu sieve script",
    "Signature …" : "Chữ ký …",
    "Save signature" : "Lưu chữ ký",
    "Set" : "Đặt",
    "Unset" : "Bỏ cài đặt",
    "Add tag" : "Thêm nhãn",
    "Tag already exists" : "Thẻ đã tồn tại",
    "Not found" : "Không tìm thấy",
    "Could not load your message thread" : "Không thể tải chuỗi tin nhắn của bạn",
    "Mark as unread" : "Đánh dấu là chưa đọc",
    "Mark as read" : "Đánh dấu đã đọc",
    "Remove" : "Xóa",
    "No senders are trusted at the moment." : "Không có người gửi nào được tin cậy vào lúc này.",
    "Could not remove trusted sender {sender}" : "Không thể xóa người gửi đáng tin cậy {sender}",
    "individual" : "Cá nhận",
    "domain" : "Miền",
    "(organizer)" : "(organizer)",
    "Untitled event" : "Sự kiện không tiêu đề",
    "Import into {calendar}" : "Nhập vào {calendar}",
    "Event imported into {calendar}" : "Sự kiện được nhập vào {calendar}",
    "Airplane" : "Máy bay",
    "Reservation {id}" : "Dự phòng {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Chuyến bay {flightNr} từ {depAirport} đến {arrAirport}",
    "Train" : "Tàu hỏa",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} từ {depStation} đến {arrStation}",
    "Train from {depStation} to {arrStation}" : "Đi tàu từ {depStation} đến {arrStation}",
    "Mail app" : "Ứng dụng thư",
    "The mail app allows users to read mails on their IMAP accounts." : "Ứng dụng thư cho phép người dùng đọc thư trên tài khoản IMAP của họ.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Tại đây bạn có thể tìm thấy các cài đặt cho toàn phiên bản. Cài đặt người dùng cụ thể được tìm thấy trong chính ứng dụng (góc dưới bên trái).",
    "Reset" : "Đặt lại",
    "Client ID" : "ID khách hàng",
    "Email: {email}" : "Thư điện tử: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} trên {host}: {port} (mã hóa {ssl})",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} trên {host}: {port} (mã hóa {ssl})",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} trên {host}: {port} (mã hóa {ssl})",
    "General" : "Tổng hợp",
    "User" : "Người dùng",
    "Host" : "Máy chủ",
    "Port" : "Cổng",
    "Enable sieve integration" : "Bật tích hợp sieve",
    "With the settings above, the app will create account settings in the following way:" : "Với cài đặt ở trên, ứng dụng sẽ tạo cài đặt tài khoản theo cách sau:",
    "Keyboard shortcut" : "Phím tắt",
    "Keyboard shortcuts" : "Phím tắt",
    "Speed up your Mail experience with these quick shortcuts." : "Tăng tốc trải nghiệm Thư của bạn với các phím tắt nhanh này.",
    "Compose new message" : "Soạn tin nhăn mơi",
    "Newer message" : "Tin nhắn mới hơn",
    "Older message" : "Tin nhắn cũ hơn",
    "Toggle star" : "Chuyển đổi dấu sao",
    "Toggle unread" : "Chuyển đổi chưa đọc",
    "Refresh" : "Làm mới",
    "Connect your mail account" : "Kết nối tài khoản thư của bạn",
    "Itinerary for {type} is not supported yet" : "Hành trình cho {type} chưa được hỗ trợ",
    "All" : "Tất cả",
    "Archive" : "Lưu trữ",
    "Drafts" : "Bản nháp",
    "Favorites" : "Ưa thích",
    "Priority inbox" : "Hộp thư ưu tiên",
    "All inboxes" : "Tất cả hộp thư đến",
    "Inbox" : "Hộp thư đến",
    "Junk" : "Rác",
    "Sent" : "Đã gửi",
    "Trash" : "Thùng rác",
    "Error while sharing file" : "Lỗi khi chia sẻ tệp",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n tin nhắn mới \ntừ {from}"],
    "Nextcloud Mail" : "Thư vWorkspace",
    "Attachments were not copied. Please add them manually." : "Tệp đính kèm không được sao chép. Vui lòng thêm chúng theo cách thủ công.",
    "Message sent" : "Tin nhắn đã gửi",
    "Could not load {tag}{name}{endtag}" : "Không thể tải {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Đã xảy ra lỗi khi tải {tag}{name}{endtag}",
    "Could not load your message" : "Không thể tải tin nhắn của bạn",
    "Could not load the desired message" : "Không thể tải tin nhắn mong muốn",
    "Could not load the message" : "Không thể tải tin nhắn",
    "Error loading message" : "Lỗi khi tải tin nhắn",
    "Forwarding to %s" : "Chuyển tiếp tới %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Nhấp vào đây nếu bạn không được chuyển hướng tự động trong vòng vài giây tới",
    "Redirect" : "Chuyển hướng",
    "The link leads to %s" : "Liên kết dẫn đến %s",
    "Continue to %s" : "Tiếp tục %s"
},
"nplurals=1; plural=0;");
